HiCache class

缓存管理类

Properties

hashCode int
The hash code for this object.
no setterinherited
prefs ↔ SharedPreferences?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get<T>(String key) → T?
init() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → dynamic
setBoolean(String key, bool value) → dynamic
setDouble(String key, double value) → dynamic
setInt(String key, int value) → dynamic
setString(String key, String value) → dynamic
setStringList(String key, List<String> value) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getInstance() HiCache
preInit() Future<HiCache?>
预初始化,防止在调用 get 的时候,prefs 还尚未完成初始化